/********************************************************************************
** Form generated from reading UI file 'autoopenprotocolsdialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_AUTOOPENPROTOCOLSDIALOG_H
#define UI_AUTOOPENPROTOCOLSDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_AutoOpenProtocolsDialog
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *label;
    QHBoxLayout *horizontalLayout;
    QListWidget *allowedList;
    QVBoxLayout *verticalLayout_2;
    QPushButton *allowedAddButton;
    QPushButton *allowedRemoveButton;
    QSpacerItem *verticalSpacer;
    QLabel *label_2;
    QHBoxLayout *horizontalLayout_2;
    QListWidget *blockedList;
    QVBoxLayout *verticalLayout_3;
    QPushButton *blockedAddButton;
    QPushButton *blockedRemoveButton;
    QSpacerItem *verticalSpacer_2;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *AutoOpenProtocolsDialog)
    {
        if (AutoOpenProtocolsDialog->objectName().isEmpty())
            AutoOpenProtocolsDialog->setObjectName("AutoOpenProtocolsDialog");
        AutoOpenProtocolsDialog->resize(520, 386);
        verticalLayout = new QVBoxLayout(AutoOpenProtocolsDialog);
        verticalLayout->setObjectName("verticalLayout");
        label = new QLabel(AutoOpenProtocolsDialog);
        label->setObjectName("label");

        verticalLayout->addWidget(label);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        allowedList = new QListWidget(AutoOpenProtocolsDialog);
        allowedList->setObjectName("allowedList");

        horizontalLayout->addWidget(allowedList);

        verticalLayout_2 = new QVBoxLayout();
        verticalLayout_2->setObjectName("verticalLayout_2");
        allowedAddButton = new QPushButton(AutoOpenProtocolsDialog);
        allowedAddButton->setObjectName("allowedAddButton");

        verticalLayout_2->addWidget(allowedAddButton);

        allowedRemoveButton = new QPushButton(AutoOpenProtocolsDialog);
        allowedRemoveButton->setObjectName("allowedRemoveButton");

        verticalLayout_2->addWidget(allowedRemoveButton);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_2->addItem(verticalSpacer);


        horizontalLayout->addLayout(verticalLayout_2);


        verticalLayout->addLayout(horizontalLayout);

        label_2 = new QLabel(AutoOpenProtocolsDialog);
        label_2->setObjectName("label_2");

        verticalLayout->addWidget(label_2);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        blockedList = new QListWidget(AutoOpenProtocolsDialog);
        blockedList->setObjectName("blockedList");

        horizontalLayout_2->addWidget(blockedList);

        verticalLayout_3 = new QVBoxLayout();
        verticalLayout_3->setObjectName("verticalLayout_3");
        blockedAddButton = new QPushButton(AutoOpenProtocolsDialog);
        blockedAddButton->setObjectName("blockedAddButton");

        verticalLayout_3->addWidget(blockedAddButton);

        blockedRemoveButton = new QPushButton(AutoOpenProtocolsDialog);
        blockedRemoveButton->setObjectName("blockedRemoveButton");

        verticalLayout_3->addWidget(blockedRemoveButton);

        verticalSpacer_2 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_3->addItem(verticalSpacer_2);


        horizontalLayout_2->addLayout(verticalLayout_3);


        verticalLayout->addLayout(horizontalLayout_2);

        buttonBox = new QDialogButtonBox(AutoOpenProtocolsDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Orientation::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::StandardButton::Cancel|QDialogButtonBox::StandardButton::Ok|QDialogButtonBox::StandardButton::Reset);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(AutoOpenProtocolsDialog);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, AutoOpenProtocolsDialog, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, AutoOpenProtocolsDialog, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(AutoOpenProtocolsDialog);
    } // setupUi

    void retranslateUi(QDialog *AutoOpenProtocolsDialog)
    {
        AutoOpenProtocolsDialog->setWindowTitle(QCoreApplication::translate("AutoOpenProtocolsDialog", "Auto-Open Protocols", nullptr));
        label->setText(QCoreApplication::translate("AutoOpenProtocolsDialog", "<html><head/><body><p><span style=\" font-weight:700;\">Auto Open</span></p></body></html>", nullptr));
        allowedAddButton->setText(QCoreApplication::translate("AutoOpenProtocolsDialog", "Add", nullptr));
        allowedRemoveButton->setText(QCoreApplication::translate("AutoOpenProtocolsDialog", "Remove", nullptr));
        label_2->setText(QCoreApplication::translate("AutoOpenProtocolsDialog", "<html><head/><body><p><span style=\" font-weight:700;\">Blocked</span></p></body></html>", nullptr));
        blockedAddButton->setText(QCoreApplication::translate("AutoOpenProtocolsDialog", "Add", nullptr));
        blockedRemoveButton->setText(QCoreApplication::translate("AutoOpenProtocolsDialog", "Remove", nullptr));
    } // retranslateUi

};

namespace Ui {
    class AutoOpenProtocolsDialog: public Ui_AutoOpenProtocolsDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_AUTOOPENPROTOCOLSDIALOG_H
