/****************************************************************************
** Meta object code from reading C++ file 'browserwindow.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../falkon-26.04.2/src/lib/app/browserwindow.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'browserwindow.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13BrowserWindowE_t {};
} // unnamed namespace

template <> constexpr inline auto BrowserWindow::qt_create_metaobjectdata<qt_meta_tag_ZN13BrowserWindowE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "BrowserWindow",
        "startingCompleted",
        "",
        "aboutToClose",
        "addTab",
        "goHome",
        "goHomeInNewTab",
        "goBack",
        "goForward",
        "reload",
        "reloadBypassCache",
        "setWindowTitle",
        "t",
        "showWebInspector",
        "toggleWebInspector",
        "showHistoryManager",
        "toggleShowMenubar",
        "toggleShowStatusBar",
        "toggleShowBookmarksToolbar",
        "toggleShowNavigationToolbar",
        "toggleTabsOnTop",
        "enable",
        "toggleFullScreen",
        "requestHtmlFullScreen",
        "TabbedWebView*",
        "view",
        "loadActionUrl",
        "obj",
        "loadActionUrlInNewTab",
        "bookmarkPage",
        "bookmarkAllTabs",
        "loadAddress",
        "QUrl",
        "url",
        "showSource",
        "WebView*",
        "openLocation",
        "openFile",
        "closeWindow",
        "closeTab",
        "loadSettings",
        "postLaunch",
        "webSearch",
        "searchOnPage",
        "changeEncoding",
        "printPage",
        "saveSettings",
        "hideNavigationSlot"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'startingCompleted'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'aboutToClose'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'addTab'
        QtMocHelpers::SlotData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'goHome'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'goHomeInNewTab'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'goBack'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'goForward'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'reload'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'reloadBypassCache'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setWindowTitle'
        QtMocHelpers::SlotData<void(const QString &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 12 },
        }}),
        // Slot 'showWebInspector'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'toggleWebInspector'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'showHistoryManager'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'toggleShowMenubar'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'toggleShowStatusBar'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'toggleShowBookmarksToolbar'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'toggleShowNavigationToolbar'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'toggleTabsOnTop'
        QtMocHelpers::SlotData<void(bool)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 21 },
        }}),
        // Slot 'toggleFullScreen'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'requestHtmlFullScreen'
        QtMocHelpers::SlotData<void(TabbedWebView *, bool)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 24, 25 }, { QMetaType::Bool, 21 },
        }}),
        // Slot 'loadActionUrl'
        QtMocHelpers::SlotData<void(QObject *)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QObjectStar, 27 },
        }}),
        // Slot 'loadActionUrl'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'loadActionUrlInNewTab'
        QtMocHelpers::SlotData<void(QObject *)>(28, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QObjectStar, 27 },
        }}),
        // Slot 'loadActionUrlInNewTab'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'bookmarkPage'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'bookmarkAllTabs'
        QtMocHelpers::SlotData<void()>(30, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'loadAddress'
        QtMocHelpers::SlotData<void(const QUrl &)>(31, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 32, 33 },
        }}),
        // Slot 'showSource'
        QtMocHelpers::SlotData<void(WebView *)>(34, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 35, 25 },
        }}),
        // Slot 'showSource'
        QtMocHelpers::SlotData<void()>(34, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'openLocation'
        QtMocHelpers::SlotData<void()>(36, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'openFile'
        QtMocHelpers::SlotData<void()>(37, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'closeWindow'
        QtMocHelpers::SlotData<void()>(38, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'closeTab'
        QtMocHelpers::SlotData<void()>(39, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'loadSettings'
        QtMocHelpers::SlotData<void()>(40, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'postLaunch'
        QtMocHelpers::SlotData<void()>(41, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'webSearch'
        QtMocHelpers::SlotData<void()>(42, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'searchOnPage'
        QtMocHelpers::SlotData<void()>(43, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'changeEncoding'
        QtMocHelpers::SlotData<void()>(44, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'printPage'
        QtMocHelpers::SlotData<void()>(45, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'saveSettings'
        QtMocHelpers::SlotData<void()>(46, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'hideNavigationSlot'
        QtMocHelpers::SlotData<void()>(47, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<BrowserWindow, qt_meta_tag_ZN13BrowserWindowE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject BrowserWindow::staticMetaObject = { {
    QMetaObject::SuperData::link<QMainWindow::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13BrowserWindowE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13BrowserWindowE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13BrowserWindowE_t>.metaTypes,
    nullptr
} };

void BrowserWindow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<BrowserWindow *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->startingCompleted(); break;
        case 1: _t->aboutToClose(); break;
        case 2: _t->addTab(); break;
        case 3: _t->goHome(); break;
        case 4: _t->goHomeInNewTab(); break;
        case 5: _t->goBack(); break;
        case 6: _t->goForward(); break;
        case 7: _t->reload(); break;
        case 8: _t->reloadBypassCache(); break;
        case 9: _t->setWindowTitle((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 10: _t->showWebInspector(); break;
        case 11: _t->toggleWebInspector(); break;
        case 12: _t->showHistoryManager(); break;
        case 13: _t->toggleShowMenubar(); break;
        case 14: _t->toggleShowStatusBar(); break;
        case 15: _t->toggleShowBookmarksToolbar(); break;
        case 16: _t->toggleShowNavigationToolbar(); break;
        case 17: _t->toggleTabsOnTop((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 18: _t->toggleFullScreen(); break;
        case 19: _t->requestHtmlFullScreen((*reinterpret_cast<std::add_pointer_t<TabbedWebView*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 20: _t->loadActionUrl((*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[1]))); break;
        case 21: _t->loadActionUrl(); break;
        case 22: _t->loadActionUrlInNewTab((*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[1]))); break;
        case 23: _t->loadActionUrlInNewTab(); break;
        case 24: _t->bookmarkPage(); break;
        case 25: _t->bookmarkAllTabs(); break;
        case 26: _t->loadAddress((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 27: _t->showSource((*reinterpret_cast<std::add_pointer_t<WebView*>>(_a[1]))); break;
        case 28: _t->showSource(); break;
        case 29: _t->openLocation(); break;
        case 30: _t->openFile(); break;
        case 31: _t->closeWindow(); break;
        case 32: _t->closeTab(); break;
        case 33: _t->loadSettings(); break;
        case 34: _t->postLaunch(); break;
        case 35: _t->webSearch(); break;
        case 36: _t->searchOnPage(); break;
        case 37: _t->changeEncoding(); break;
        case 38: _t->printPage(); break;
        case 39: _t->saveSettings(); break;
        case 40: _t->hideNavigationSlot(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (BrowserWindow::*)()>(_a, &BrowserWindow::startingCompleted, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (BrowserWindow::*)()>(_a, &BrowserWindow::aboutToClose, 1))
            return;
    }
}

const QMetaObject *BrowserWindow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *BrowserWindow::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13BrowserWindowE_t>.strings))
        return static_cast<void*>(this);
    return QMainWindow::qt_metacast(_clname);
}

int BrowserWindow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QMainWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 41)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 41;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 41)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 41;
    }
    return _id;
}

// SIGNAL 0
void BrowserWindow::startingCompleted()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void BrowserWindow::aboutToClose()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
QT_WARNING_POP
