/****************************************************************************
** Meta object code from reading C++ file 'sessionmanager.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../falkon-26.04.2/src/lib/session/sessionmanager.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'sessionmanager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN14SessionManagerE_t {};
} // unnamed namespace

template <> constexpr inline auto SessionManager::qt_create_metaobjectdata<qt_meta_tag_ZN14SessionManagerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "SessionManager",
        "sessionsMetaDataChanged",
        "",
        "autoSaveLastSession",
        "openSessionManagerDialog",
        "aboutToShowSessionsMenu",
        "sessionsDirectoryChanged",
        "openSession",
        "sessionFilePath",
        "SessionManager::SessionFlags",
        "flags",
        "renameSession",
        "saveSession",
        "replaceSession",
        "filePath",
        "switchToSession",
        "cloneSession",
        "deleteSession",
        "newSession",
        "sessionMetaData",
        "QList<SessionManager::SessionMetaData>",
        "withBackups"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'sessionsMetaDataChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'autoSaveLastSession'
        QtMocHelpers::SlotData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'openSessionManagerDialog'
        QtMocHelpers::SlotData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'aboutToShowSessionsMenu'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'sessionsDirectoryChanged'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'openSession'
        QtMocHelpers::SlotData<void(QString, SessionManager::SessionFlags)>(7, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 8 }, { 0x80000000 | 9, 10 },
        }}),
        // Slot 'openSession'
        QtMocHelpers::SlotData<void(QString)>(7, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 8 },
        }}),
        // Slot 'openSession'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void),
        // Slot 'renameSession'
        QtMocHelpers::SlotData<void(QString, SessionManager::SessionFlags)>(11, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 8 }, { 0x80000000 | 9, 10 },
        }}),
        // Slot 'renameSession'
        QtMocHelpers::SlotData<void(QString)>(11, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 8 },
        }}),
        // Slot 'renameSession'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void),
        // Slot 'saveSession'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'replaceSession'
        QtMocHelpers::SlotData<void(const QString &)>(13, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 14 },
        }}),
        // Slot 'switchToSession'
        QtMocHelpers::SlotData<void(const QString &)>(15, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 14 },
        }}),
        // Slot 'cloneSession'
        QtMocHelpers::SlotData<void(const QString &)>(16, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 14 },
        }}),
        // Slot 'deleteSession'
        QtMocHelpers::SlotData<void(const QString &)>(17, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 14 },
        }}),
        // Slot 'newSession'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'sessionMetaData'
        QtMocHelpers::SlotData<QList<SessionManager::SessionMetaData>(bool)>(19, 2, QMC::AccessPrivate, 0x80000000 | 20, {{
            { QMetaType::Bool, 21 },
        }}),
        // Slot 'sessionMetaData'
        QtMocHelpers::SlotData<QList<SessionManager::SessionMetaData>()>(19, 2, QMC::AccessPrivate | QMC::MethodCloned, 0x80000000 | 20),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<SessionManager, qt_meta_tag_ZN14SessionManagerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject SessionManager::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14SessionManagerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14SessionManagerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14SessionManagerE_t>.metaTypes,
    nullptr
} };

void SessionManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SessionManager *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->sessionsMetaDataChanged(); break;
        case 1: _t->autoSaveLastSession(); break;
        case 2: _t->openSessionManagerDialog(); break;
        case 3: _t->aboutToShowSessionsMenu(); break;
        case 4: _t->sessionsDirectoryChanged(); break;
        case 5: _t->openSession((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<SessionManager::SessionFlags>>(_a[2]))); break;
        case 6: _t->openSession((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 7: _t->openSession(); break;
        case 8: _t->renameSession((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<SessionManager::SessionFlags>>(_a[2]))); break;
        case 9: _t->renameSession((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 10: _t->renameSession(); break;
        case 11: _t->saveSession(); break;
        case 12: _t->replaceSession((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 13: _t->switchToSession((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 14: _t->cloneSession((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 15: _t->deleteSession((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 16: _t->newSession(); break;
        case 17: { QList<SessionManager::SessionMetaData> _r = _t->sessionMetaData((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QList<SessionManager::SessionMetaData>*>(_a[0]) = std::move(_r); }  break;
        case 18: { QList<SessionManager::SessionMetaData> _r = _t->sessionMetaData();
            if (_a[0]) *reinterpret_cast<QList<SessionManager::SessionMetaData>*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (SessionManager::*)()>(_a, &SessionManager::sessionsMetaDataChanged, 0))
            return;
    }
}

const QMetaObject *SessionManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SessionManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14SessionManagerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int SessionManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 19)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 19;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 19)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 19;
    }
    return _id;
}

// SIGNAL 0
void SessionManager::sessionsMetaDataChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
QT_WARNING_POP
