/****************************************************************************
** Meta object code from reading C++ file 'webview.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../falkon-26.04.2/src/lib/webengine/webview.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'webview.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7WebViewE_t {};
} // unnamed namespace

template <> constexpr inline auto WebView::qt_create_metaobjectdata<qt_meta_tag_ZN7WebViewE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "WebView",
        "pageChanged",
        "",
        "WebPage*",
        "page",
        "focusChanged",
        "viewportResized",
        "QSize",
        "showNotification",
        "QWidget*",
        "privacyChanged",
        "zoomLevelChanged",
        "backgroundActivityChanged",
        "zoomIn",
        "zoomOut",
        "zoomReset",
        "editUndo",
        "editRedo",
        "editCut",
        "editCopy",
        "editPaste",
        "editSelectAll",
        "editDelete",
        "reloadBypassCache",
        "back",
        "forward",
        "printPage",
        "showSource",
        "sendPageByMail",
        "openUrlInNewTab",
        "QUrl",
        "url",
        "Qz::NewTabPositionFlags",
        "position",
        "closeView",
        "loadInNewTab",
        "LoadRequest",
        "req",
        "isFullScreen",
        "requestFullScreen",
        "enable",
        "slotLoadStarted",
        "slotLoadProgress",
        "progress",
        "slotLoadFinished",
        "ok",
        "slotIconChanged",
        "slotUrlChanged",
        "slotTitleChanged",
        "title",
        "slotPrintFinished",
        "success",
        "openUrlInNewWindow",
        "sendTextByMail",
        "copyLinkToClipboard",
        "savePageAs",
        "copyImageToClipboard",
        "downloadLinkToDisk",
        "downloadImageToDisk",
        "downloadMediaToDisk",
        "openActionUrl",
        "showSiteInfo",
        "searchSelectedText",
        "searchSelectedTextInBackgroundTab",
        "bookmarkLink",
        "openUrlInSelectedTab",
        "openUrlInBackgroundTab",
        "userDefinedOpenUrlInNewTab",
        "invert",
        "userDefinedOpenUrlInBgTab",
        "addSpeedDial",
        "configureSpeedDial",
        "reloadAllSpeedDials",
        "toggleMediaPause",
        "toggleMediaMute"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'pageChanged'
        QtMocHelpers::SignalData<void(WebPage *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'focusChanged'
        QtMocHelpers::SignalData<void(bool)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'viewportResized'
        QtMocHelpers::SignalData<void(QSize)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 2 },
        }}),
        // Signal 'showNotification'
        QtMocHelpers::SignalData<void(QWidget *)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 2 },
        }}),
        // Signal 'privacyChanged'
        QtMocHelpers::SignalData<void(bool)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'zoomLevelChanged'
        QtMocHelpers::SignalData<void(int)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Signal 'backgroundActivityChanged'
        QtMocHelpers::SignalData<void(bool)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'zoomIn'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'zoomOut'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'zoomReset'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'editUndo'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'editRedo'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'editCut'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'editCopy'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'editPaste'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'editSelectAll'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'editDelete'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'reloadBypassCache'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'back'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'forward'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'printPage'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'showSource'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'sendPageByMail'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'openUrlInNewTab'
        QtMocHelpers::SlotData<void(const QUrl &, Qz::NewTabPositionFlags)>(29, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 30, 31 }, { 0x80000000 | 32, 33 },
        }}),
        // Slot 'closeView'
        QtMocHelpers::SlotData<void()>(34, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'loadInNewTab'
        QtMocHelpers::SlotData<void(const LoadRequest &, Qz::NewTabPositionFlags)>(35, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 36, 37 }, { 0x80000000 | 32, 33 },
        }}),
        // Slot 'isFullScreen'
        QtMocHelpers::SlotData<bool()>(38, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'requestFullScreen'
        QtMocHelpers::SlotData<void(bool)>(39, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 40 },
        }}),
        // Slot 'slotLoadStarted'
        QtMocHelpers::SlotData<void()>(41, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotLoadProgress'
        QtMocHelpers::SlotData<void(int)>(42, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Int, 43 },
        }}),
        // Slot 'slotLoadFinished'
        QtMocHelpers::SlotData<void(bool)>(44, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Bool, 45 },
        }}),
        // Slot 'slotIconChanged'
        QtMocHelpers::SlotData<void()>(46, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotUrlChanged'
        QtMocHelpers::SlotData<void(const QUrl &)>(47, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 30, 31 },
        }}),
        // Slot 'slotTitleChanged'
        QtMocHelpers::SlotData<void(const QString &)>(48, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QString, 49 },
        }}),
        // Slot 'slotPrintFinished'
        QtMocHelpers::SlotData<void(bool)>(50, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Bool, 51 },
        }}),
        // Slot 'openUrlInNewWindow'
        QtMocHelpers::SlotData<void()>(52, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'sendTextByMail'
        QtMocHelpers::SlotData<void()>(53, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'copyLinkToClipboard'
        QtMocHelpers::SlotData<void()>(54, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'savePageAs'
        QtMocHelpers::SlotData<void()>(55, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'copyImageToClipboard'
        QtMocHelpers::SlotData<void()>(56, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'downloadLinkToDisk'
        QtMocHelpers::SlotData<void()>(57, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'downloadImageToDisk'
        QtMocHelpers::SlotData<void()>(58, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'downloadMediaToDisk'
        QtMocHelpers::SlotData<void()>(59, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'openActionUrl'
        QtMocHelpers::SlotData<void()>(60, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'showSiteInfo'
        QtMocHelpers::SlotData<void()>(61, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'searchSelectedText'
        QtMocHelpers::SlotData<void()>(62, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'searchSelectedTextInBackgroundTab'
        QtMocHelpers::SlotData<void()>(63, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'bookmarkLink'
        QtMocHelpers::SlotData<void()>(64, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'openUrlInSelectedTab'
        QtMocHelpers::SlotData<void()>(65, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'openUrlInBackgroundTab'
        QtMocHelpers::SlotData<void()>(66, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'userDefinedOpenUrlInNewTab'
        QtMocHelpers::SlotData<void(const QUrl &, bool)>(67, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 30, 31 }, { QMetaType::Bool, 68 },
        }}),
        // Slot 'userDefinedOpenUrlInNewTab'
        QtMocHelpers::SlotData<void(const QUrl &)>(67, 2, QMC::AccessProtected | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 30, 31 },
        }}),
        // Slot 'userDefinedOpenUrlInNewTab'
        QtMocHelpers::SlotData<void()>(67, 2, QMC::AccessProtected | QMC::MethodCloned, QMetaType::Void),
        // Slot 'userDefinedOpenUrlInBgTab'
        QtMocHelpers::SlotData<void(const QUrl &)>(69, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 30, 31 },
        }}),
        // Slot 'userDefinedOpenUrlInBgTab'
        QtMocHelpers::SlotData<void()>(69, 2, QMC::AccessProtected | QMC::MethodCloned, QMetaType::Void),
        // Slot 'addSpeedDial'
        QtMocHelpers::SlotData<void()>(70, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'configureSpeedDial'
        QtMocHelpers::SlotData<void()>(71, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'reloadAllSpeedDials'
        QtMocHelpers::SlotData<void()>(72, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'toggleMediaPause'
        QtMocHelpers::SlotData<void()>(73, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'toggleMediaMute'
        QtMocHelpers::SlotData<void()>(74, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<WebView, qt_meta_tag_ZN7WebViewE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject WebView::staticMetaObject = { {
    QMetaObject::SuperData::link<QWebEngineView::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7WebViewE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7WebViewE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7WebViewE_t>.metaTypes,
    nullptr
} };

void WebView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<WebView *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->pageChanged((*reinterpret_cast<std::add_pointer_t<WebPage*>>(_a[1]))); break;
        case 1: _t->focusChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 2: _t->viewportResized((*reinterpret_cast<std::add_pointer_t<QSize>>(_a[1]))); break;
        case 3: _t->showNotification((*reinterpret_cast<std::add_pointer_t<QWidget*>>(_a[1]))); break;
        case 4: _t->privacyChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 5: _t->zoomLevelChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 6: _t->backgroundActivityChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 7: _t->zoomIn(); break;
        case 8: _t->zoomOut(); break;
        case 9: _t->zoomReset(); break;
        case 10: _t->editUndo(); break;
        case 11: _t->editRedo(); break;
        case 12: _t->editCut(); break;
        case 13: _t->editCopy(); break;
        case 14: _t->editPaste(); break;
        case 15: _t->editSelectAll(); break;
        case 16: _t->editDelete(); break;
        case 17: _t->reloadBypassCache(); break;
        case 18: _t->back(); break;
        case 19: _t->forward(); break;
        case 20: _t->printPage(); break;
        case 21: _t->showSource(); break;
        case 22: _t->sendPageByMail(); break;
        case 23: _t->openUrlInNewTab((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Qz::NewTabPositionFlags>>(_a[2]))); break;
        case 24: _t->closeView(); break;
        case 25: _t->loadInNewTab((*reinterpret_cast<std::add_pointer_t<LoadRequest>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Qz::NewTabPositionFlags>>(_a[2]))); break;
        case 26: { bool _r = _t->isFullScreen();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 27: _t->requestFullScreen((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 28: _t->slotLoadStarted(); break;
        case 29: _t->slotLoadProgress((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 30: _t->slotLoadFinished((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 31: _t->slotIconChanged(); break;
        case 32: _t->slotUrlChanged((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 33: _t->slotTitleChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 34: _t->slotPrintFinished((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 35: _t->openUrlInNewWindow(); break;
        case 36: _t->sendTextByMail(); break;
        case 37: _t->copyLinkToClipboard(); break;
        case 38: _t->savePageAs(); break;
        case 39: _t->copyImageToClipboard(); break;
        case 40: _t->downloadLinkToDisk(); break;
        case 41: _t->downloadImageToDisk(); break;
        case 42: _t->downloadMediaToDisk(); break;
        case 43: _t->openActionUrl(); break;
        case 44: _t->showSiteInfo(); break;
        case 45: _t->searchSelectedText(); break;
        case 46: _t->searchSelectedTextInBackgroundTab(); break;
        case 47: _t->bookmarkLink(); break;
        case 48: _t->openUrlInSelectedTab(); break;
        case 49: _t->openUrlInBackgroundTab(); break;
        case 50: _t->userDefinedOpenUrlInNewTab((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 51: _t->userDefinedOpenUrlInNewTab((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 52: _t->userDefinedOpenUrlInNewTab(); break;
        case 53: _t->userDefinedOpenUrlInBgTab((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 54: _t->userDefinedOpenUrlInBgTab(); break;
        case 55: _t->addSpeedDial(); break;
        case 56: _t->configureSpeedDial(); break;
        case 57: _t->reloadAllSpeedDials(); break;
        case 58: _t->toggleMediaPause(); break;
        case 59: _t->toggleMediaMute(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QWidget* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (WebView::*)(WebPage * )>(_a, &WebView::pageChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (WebView::*)(bool )>(_a, &WebView::focusChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (WebView::*)(QSize )>(_a, &WebView::viewportResized, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (WebView::*)(QWidget * )>(_a, &WebView::showNotification, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (WebView::*)(bool )>(_a, &WebView::privacyChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (WebView::*)(int )>(_a, &WebView::zoomLevelChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (WebView::*)(bool )>(_a, &WebView::backgroundActivityChanged, 6))
            return;
    }
}

const QMetaObject *WebView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *WebView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7WebViewE_t>.strings))
        return static_cast<void*>(this);
    return QWebEngineView::qt_metacast(_clname);
}

int WebView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWebEngineView::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 60)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 60;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 60)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 60;
    }
    return _id;
}

// SIGNAL 0
void WebView::pageChanged(WebPage * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void WebView::focusChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void WebView::viewportResized(QSize _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void WebView::showNotification(QWidget * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void WebView::privacyChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void WebView::zoomLevelChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void WebView::backgroundActivityChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}
QT_WARNING_POP
