/****************************************************************************
** Meta object code from reading C++ file 'qmlwebhittestresult.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../falkon-26.04.2/src/lib/plugins/qml/api/menus/qmlwebhittestresult.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qmlwebhittestresult.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN19QmlWebHitTestResultE_t {};
} // unnamed namespace

template <> constexpr inline auto QmlWebHitTestResult::qt_create_metaobjectdata<qt_meta_tag_ZN19QmlWebHitTestResultE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QmlWebHitTestResult",
        "isImage",
        "",
        "isContentEditable",
        "isContentSelected",
        "isNull",
        "isLink",
        "isMedia",
        "mediaPaused",
        "mediaMuted",
        "tagName",
        "baseUrl",
        "linkTitle",
        "linkUrl",
        "imageUrl",
        "mediaUrl",
        "pos",
        "QPoint",
        "viewportPos",
        "QPointF"
    };

    QtMocHelpers::UintData qt_methods {
        // Method 'isImage'
        QtMocHelpers::MethodData<bool() const>(1, 2, QMC::AccessPublic, QMetaType::Bool),
        // Method 'isContentEditable'
        QtMocHelpers::MethodData<bool() const>(3, 2, QMC::AccessPublic, QMetaType::Bool),
        // Method 'isContentSelected'
        QtMocHelpers::MethodData<bool() const>(4, 2, QMC::AccessPublic, QMetaType::Bool),
        // Method 'isNull'
        QtMocHelpers::MethodData<bool() const>(5, 2, QMC::AccessPublic, QMetaType::Bool),
        // Method 'isLink'
        QtMocHelpers::MethodData<bool() const>(6, 2, QMC::AccessPublic, QMetaType::Bool),
        // Method 'isMedia'
        QtMocHelpers::MethodData<bool() const>(7, 2, QMC::AccessPublic, QMetaType::Bool),
        // Method 'mediaPaused'
        QtMocHelpers::MethodData<bool() const>(8, 2, QMC::AccessPublic, QMetaType::Bool),
        // Method 'mediaMuted'
        QtMocHelpers::MethodData<bool() const>(9, 2, QMC::AccessPublic, QMetaType::Bool),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'tagName'
        QtMocHelpers::PropertyData<QString>(10, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'baseUrl'
        QtMocHelpers::PropertyData<QString>(11, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'linkTitle'
        QtMocHelpers::PropertyData<QString>(12, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'linkUrl'
        QtMocHelpers::PropertyData<QString>(13, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'imageUrl'
        QtMocHelpers::PropertyData<QString>(14, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'mediaUrl'
        QtMocHelpers::PropertyData<QString>(15, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'pos'
        QtMocHelpers::PropertyData<QPoint>(16, 0x80000000 | 17, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'viewportPos'
        QtMocHelpers::PropertyData<QPointF>(18, 0x80000000 | 19, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<QmlWebHitTestResult, qt_meta_tag_ZN19QmlWebHitTestResultE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject QmlWebHitTestResult::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19QmlWebHitTestResultE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19QmlWebHitTestResultE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19QmlWebHitTestResultE_t>.metaTypes,
    nullptr
} };

void QmlWebHitTestResult::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QmlWebHitTestResult *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { bool _r = _t->isImage();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 1: { bool _r = _t->isContentEditable();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 2: { bool _r = _t->isContentSelected();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 3: { bool _r = _t->isNull();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 4: { bool _r = _t->isLink();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 5: { bool _r = _t->isMedia();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 6: { bool _r = _t->mediaPaused();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 7: { bool _r = _t->mediaMuted();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->tagName(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->baseUrl(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->linkTitle(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->linkUrl(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->imageUrl(); break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->mediaUrl(); break;
        case 6: *reinterpret_cast<QPoint*>(_v) = _t->pos(); break;
        case 7: *reinterpret_cast<QPointF*>(_v) = _t->viewportPos(); break;
        default: break;
        }
    }
}

const QMetaObject *QmlWebHitTestResult::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QmlWebHitTestResult::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19QmlWebHitTestResultE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int QmlWebHitTestResult::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 8;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    return _id;
}
QT_WARNING_POP
