/********************************************************************************
** Form generated from reading UI file 'downloadmanager.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_DOWNLOADMANAGER_H
#define UI_DOWNLOADMANAGER_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_DownloadManager
{
public:
    QVBoxLayout *verticalLayout;
    QListWidget *list;
    QHBoxLayout *horizontalLayout;
    QSpacerItem *horizontalSpacer_2;
    QPushButton *clearButton;
    QSpacerItem *horizontalSpacer;
    QLabel *speedLabel;
    QSpacerItem *horizontalSpacer_3;

    void setupUi(QWidget *DownloadManager)
    {
        if (DownloadManager->objectName().isEmpty())
            DownloadManager->setObjectName("DownloadManager");
        DownloadManager->resize(525, 315);
        DownloadManager->setMinimumSize(QSize(300, 0));
        verticalLayout = new QVBoxLayout(DownloadManager);
        verticalLayout->setSpacing(0);
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        verticalLayout->setObjectName("verticalLayout");
        list = new QListWidget(DownloadManager);
        list->setObjectName("list");
        list->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
        list->setAlternatingRowColors(true);
        list->setVerticalScrollMode(QAbstractItemView::ScrollPerPixel);

        verticalLayout->addWidget(list);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalSpacer_2 = new QSpacerItem(2, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer_2);

        clearButton = new QPushButton(DownloadManager);
        clearButton->setObjectName("clearButton");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(clearButton->sizePolicy().hasHeightForWidth());
        clearButton->setSizePolicy(sizePolicy);

        horizontalLayout->addWidget(clearButton);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        speedLabel = new QLabel(DownloadManager);
        speedLabel->setObjectName("speedLabel");

        horizontalLayout->addWidget(speedLabel);

        horizontalSpacer_3 = new QSpacerItem(40, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer_3);


        verticalLayout->addLayout(horizontalLayout);


        retranslateUi(DownloadManager);

        QMetaObject::connectSlotsByName(DownloadManager);
    } // setupUi

    void retranslateUi(QWidget *DownloadManager)
    {
        DownloadManager->setWindowTitle(QCoreApplication::translate("DownloadManager", "Download Manager", nullptr));
        clearButton->setText(QCoreApplication::translate("DownloadManager", "Clear", nullptr));
    } // retranslateUi

};

namespace Ui {
    class DownloadManager: public Ui_DownloadManager {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_DOWNLOADMANAGER_H
