/********************************************************************************
** Form generated from reading UI file 'navigationbarconfigdialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_NAVIGATIONBARCONFIGDIALOG_H
#define UI_NAVIGATIONBARCONFIGDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QSpacerItem>

QT_BEGIN_NAMESPACE

class Ui_NavigationBarConfigDialog
{
public:
    QGridLayout *gridLayout;
    QDialogButtonBox *buttonBox;
    QListWidget *currentItems;
    QSpacerItem *verticalSpacer;
    QCheckBox *showSearchBar;
    QListWidget *availableItems;
    QLabel *label;
    QLabel *label_2;

    void setupUi(QDialog *NavigationBarConfigDialog)
    {
        if (NavigationBarConfigDialog->objectName().isEmpty())
            NavigationBarConfigDialog->setObjectName("NavigationBarConfigDialog");
        NavigationBarConfigDialog->resize(674, 466);
        gridLayout = new QGridLayout(NavigationBarConfigDialog);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setHorizontalSpacing(50);
        buttonBox = new QDialogButtonBox(NavigationBarConfigDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::Apply|QDialogButtonBox::Cancel|QDialogButtonBox::Ok|QDialogButtonBox::RestoreDefaults);

        gridLayout->addWidget(buttonBox, 4, 0, 1, 2);

        currentItems = new QListWidget(NavigationBarConfigDialog);
        currentItems->setObjectName("currentItems");
        currentItems->setAcceptDrops(true);
        currentItems->setDragEnabled(true);
        currentItems->setDragDropMode(QAbstractItemView::DragDrop);
        currentItems->setDefaultDropAction(Qt::MoveAction);

        gridLayout->addWidget(currentItems, 1, 1, 1, 1);

        verticalSpacer = new QSpacerItem(20, 10, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer, 2, 0, 1, 1);

        showSearchBar = new QCheckBox(NavigationBarConfigDialog);
        showSearchBar->setObjectName("showSearchBar");

        gridLayout->addWidget(showSearchBar, 3, 0, 1, 2);

        availableItems = new QListWidget(NavigationBarConfigDialog);
        availableItems->setObjectName("availableItems");
        availableItems->setDragEnabled(true);
        availableItems->setDragDropMode(QAbstractItemView::DragDrop);
        availableItems->setDefaultDropAction(Qt::MoveAction);

        gridLayout->addWidget(availableItems, 1, 0, 1, 1);

        label = new QLabel(NavigationBarConfigDialog);
        label->setObjectName("label");

        gridLayout->addWidget(label, 0, 0, 1, 1);

        label_2 = new QLabel(NavigationBarConfigDialog);
        label_2->setObjectName("label_2");

        gridLayout->addWidget(label_2, 0, 1, 1, 1);


        retranslateUi(NavigationBarConfigDialog);

        QMetaObject::connectSlotsByName(NavigationBarConfigDialog);
    } // setupUi

    void retranslateUi(QDialog *NavigationBarConfigDialog)
    {
        NavigationBarConfigDialog->setWindowTitle(QCoreApplication::translate("NavigationBarConfigDialog", "Configure Toolbar", nullptr));
        showSearchBar->setText(QCoreApplication::translate("NavigationBarConfigDialog", "Show search bar", nullptr));
        label->setText(QCoreApplication::translate("NavigationBarConfigDialog", "Available items:", nullptr));
        label_2->setText(QCoreApplication::translate("NavigationBarConfigDialog", "Current items:", nullptr));
    } // retranslateUi

};

namespace Ui {
    class NavigationBarConfigDialog: public Ui_NavigationBarConfigDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_NAVIGATIONBARCONFIGDIALOG_H
