/********************************************************************************
** Form generated from reading UI file 'bookmarkssidebar.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_BOOKMARKSSIDEBAR_H
#define UI_BOOKMARKSSIDEBAR_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "bookmarkstreeview.h"

QT_BEGIN_NAMESPACE

class Ui_BookmarksSideBar
{
public:
    QVBoxLayout *verticalLayout;
    QWidget *widget;
    QGridLayout *gridLayout;
    QLineEdit *search;
    BookmarksTreeView *tree;

    void setupUi(QWidget *BookmarksSideBar)
    {
        if (BookmarksSideBar->objectName().isEmpty())
            BookmarksSideBar->setObjectName("BookmarksSideBar");
        BookmarksSideBar->resize(150, 486);
        verticalLayout = new QVBoxLayout(BookmarksSideBar);
        verticalLayout->setSpacing(1);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 2, 0, 0);
        widget = new QWidget(BookmarksSideBar);
        widget->setObjectName("widget");
        gridLayout = new QGridLayout(widget);
        gridLayout->setSpacing(0);
        gridLayout->setContentsMargins(0, 0, 0, 0);
        gridLayout->setObjectName("gridLayout");
        search = new QLineEdit(widget);
        search->setObjectName("search");

        gridLayout->addWidget(search, 0, 0, 1, 1);

        tree = new BookmarksTreeView(widget);
        tree->setObjectName("tree");

        gridLayout->addWidget(tree, 1, 0, 1, 1);


        verticalLayout->addWidget(widget);


        retranslateUi(BookmarksSideBar);

        QMetaObject::connectSlotsByName(BookmarksSideBar);
    } // setupUi

    void retranslateUi(QWidget *BookmarksSideBar)
    {
        search->setPlaceholderText(QCoreApplication::translate("BookmarksSideBar", "Search...", nullptr));
        (void)BookmarksSideBar;
    } // retranslateUi

};

namespace Ui {
    class BookmarksSideBar: public Ui_BookmarksSideBar {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_BOOKMARKSSIDEBAR_H
