/********************************************************************************
** Form generated from reading UI file 'gm_notification.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_GM_NOTIFICATION_H
#define UI_GM_NOTIFICATION_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include "mactoolbutton.h"

QT_BEGIN_NAMESPACE

class Ui_GM_Notification
{
public:
    QHBoxLayout *horizontalLayout;
    QLabel *iconLabel;
    QLabel *label_2;
    QSpacerItem *horizontalSpacer;
    QPushButton *install;
    MacToolButton *close;

    void setupUi(QWidget *GM_Notification)
    {
        if (GM_Notification->objectName().isEmpty())
            GM_Notification->setObjectName("GM_Notification");
        GM_Notification->resize(820, 36);
        horizontalLayout = new QHBoxLayout(GM_Notification);
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalLayout->setContentsMargins(-1, 0, -1, 0);
        iconLabel = new QLabel(GM_Notification);
        iconLabel->setObjectName("iconLabel");
        iconLabel->setMinimumSize(QSize(24, 24));
        iconLabel->setMaximumSize(QSize(24, 24));

        horizontalLayout->addWidget(iconLabel);

        label_2 = new QLabel(GM_Notification);
        label_2->setObjectName("label_2");

        horizontalLayout->addWidget(label_2);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        install = new QPushButton(GM_Notification);
        install->setObjectName("install");

        horizontalLayout->addWidget(install);

        close = new MacToolButton(GM_Notification);
        close->setObjectName("close");
        close->setAutoRaise(true);

        horizontalLayout->addWidget(close);


        retranslateUi(GM_Notification);

        QMetaObject::connectSlotsByName(GM_Notification);
    } // setupUi

    void retranslateUi(QWidget *GM_Notification)
    {
        label_2->setText(QCoreApplication::translate("GM_Notification", "This script can be installed with the GreaseMonkey plugin.", nullptr));
        install->setText(QCoreApplication::translate("GM_Notification", "Install", nullptr));
        close->setText(QString());
        (void)GM_Notification;
    } // retranslateUi

};

namespace Ui {
    class GM_Notification: public Ui_GM_Notification {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_GM_NOTIFICATION_H
