// This file is autogenerated. Changes will be overwritten.
#include "WWFCTI4UCT/moc_QjtMouseGesture.cpp"
#include "EWIEGA46WW/moc_mousegestures.cpp"
#include "EWIEGA46WW/moc_mousegesturesplugin.cpp"
#include "EWIEGA46WW/moc_mousegesturessettingsdialog.cpp"
