/********************************************************************************
** Form generated from reading UI file 'verticaltabssettings.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_VERTICALTABSSETTINGS_H
#define UI_VERTICALTABSSETTINGS_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_VerticalTabsSettings
{
public:
    QVBoxLayout *verticalLayout_2;
    QGroupBox *groupBox;
    QVBoxLayout *verticalLayout;
    QRadioButton *tabListView;
    QRadioButton *tabTreeView;
    QGroupBox *groupBox_2;
    QFormLayout *formLayout;
    QRadioButton *appendChild;
    QRadioButton *prependChild;
    QLabel *label;
    QComboBox *theme;
    QCheckBox *replaceTabBar;
    QSpacerItem *verticalSpacer;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *VerticalTabsSettings)
    {
        if (VerticalTabsSettings->objectName().isEmpty())
            VerticalTabsSettings->setObjectName("VerticalTabsSettings");
        VerticalTabsSettings->resize(460, 344);
        verticalLayout_2 = new QVBoxLayout(VerticalTabsSettings);
        verticalLayout_2->setObjectName("verticalLayout_2");
        groupBox = new QGroupBox(VerticalTabsSettings);
        groupBox->setObjectName("groupBox");
        verticalLayout = new QVBoxLayout(groupBox);
        verticalLayout->setObjectName("verticalLayout");
        tabListView = new QRadioButton(groupBox);
        tabListView->setObjectName("tabListView");

        verticalLayout->addWidget(tabListView);

        tabTreeView = new QRadioButton(groupBox);
        tabTreeView->setObjectName("tabTreeView");

        verticalLayout->addWidget(tabTreeView);


        verticalLayout_2->addWidget(groupBox);

        groupBox_2 = new QGroupBox(VerticalTabsSettings);
        groupBox_2->setObjectName("groupBox_2");
        formLayout = new QFormLayout(groupBox_2);
        formLayout->setObjectName("formLayout");
        appendChild = new QRadioButton(groupBox_2);
        appendChild->setObjectName("appendChild");

        formLayout->setWidget(0, QFormLayout::ItemRole::SpanningRole, appendChild);

        prependChild = new QRadioButton(groupBox_2);
        prependChild->setObjectName("prependChild");

        formLayout->setWidget(1, QFormLayout::ItemRole::SpanningRole, prependChild);

        label = new QLabel(groupBox_2);
        label->setObjectName("label");

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, label);

        theme = new QComboBox(groupBox_2);
        theme->setObjectName("theme");

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, theme);


        verticalLayout_2->addWidget(groupBox_2);

        replaceTabBar = new QCheckBox(VerticalTabsSettings);
        replaceTabBar->setObjectName("replaceTabBar");

        verticalLayout_2->addWidget(replaceTabBar);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_2->addItem(verticalSpacer);

        buttonBox = new QDialogButtonBox(VerticalTabsSettings);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout_2->addWidget(buttonBox);


        retranslateUi(VerticalTabsSettings);

        QMetaObject::connectSlotsByName(VerticalTabsSettings);
    } // setupUi

    void retranslateUi(QDialog *VerticalTabsSettings)
    {
        VerticalTabsSettings->setWindowTitle(QCoreApplication::translate("VerticalTabsSettings", "Vertical Tabs Settings", nullptr));
        groupBox->setTitle(QCoreApplication::translate("VerticalTabsSettings", "View", nullptr));
        tabListView->setText(QCoreApplication::translate("VerticalTabsSettings", "Tab List", nullptr));
        tabTreeView->setText(QCoreApplication::translate("VerticalTabsSettings", "Tab Tree", nullptr));
        groupBox_2->setTitle(QCoreApplication::translate("VerticalTabsSettings", "Options", nullptr));
        appendChild->setText(QCoreApplication::translate("VerticalTabsSettings", "Add new child tabs to the end of tab tree", nullptr));
        prependChild->setText(QCoreApplication::translate("VerticalTabsSettings", "Add new child tabs to the beginning of tab tree", nullptr));
        label->setText(QCoreApplication::translate("VerticalTabsSettings", "Theme:", nullptr));
        replaceTabBar->setText(QCoreApplication::translate("VerticalTabsSettings", "Use as replacement for main tab bar", nullptr));
    } // retranslateUi

};

namespace Ui {
    class VerticalTabsSettings: public Ui_VerticalTabsSettings {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_VERTICALTABSSETTINGS_H
