/********************************************************************************
** Form generated from reading UI file 'sslerrordialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SSLERRORDIALOG_H
#define UI_SSLERRORDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_SslErrorDialog
{
public:
    QGridLayout *gridLayout;
    QLabel *icon;
    QHBoxLayout *horizontalLayout_2;
    QSpacerItem *horizontalSpacer_3;
    QDialogButtonBox *buttonBox;
    QSpacerItem *horizontalSpacer_4;
    QLabel *text;
    QVBoxLayout *verticalLayout;
    QHBoxLayout *certificateLayout;
    QPushButton *certDetailsButton;
    QSpacerItem *horizontalSpacer;
    QTabWidget *certTabWidget;
    QSpacerItem *verticalSpacer;

    void setupUi(QDialog *SslErrorDialog)
    {
        if (SslErrorDialog->objectName().isEmpty())
            SslErrorDialog->setObjectName("SslErrorDialog");
        SslErrorDialog->resize(511, 366);
        gridLayout = new QGridLayout(SslErrorDialog);
        gridLayout->setObjectName("gridLayout");
        icon = new QLabel(SslErrorDialog);
        icon->setObjectName("icon");
        icon->setAlignment(Qt::AlignmentFlag::AlignLeading|Qt::AlignmentFlag::AlignLeft|Qt::AlignmentFlag::AlignTop);

        gridLayout->addWidget(icon, 0, 0, 1, 1);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        horizontalSpacer_3 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_3);

        buttonBox = new QDialogButtonBox(SslErrorDialog);
        buttonBox->setObjectName("buttonBox");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(buttonBox->sizePolicy().hasHeightForWidth());
        buttonBox->setSizePolicy(sizePolicy);
        buttonBox->setOrientation(Qt::Orientation::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::StandardButton::No|QDialogButtonBox::StandardButton::Yes);

        horizontalLayout_2->addWidget(buttonBox);

        horizontalSpacer_4 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_4);


        gridLayout->addLayout(horizontalLayout_2, 2, 0, 1, 3);

        text = new QLabel(SslErrorDialog);
        text->setObjectName("text");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::MinimumExpanding);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(text->sizePolicy().hasHeightForWidth());
        text->setSizePolicy(sizePolicy1);
        text->setAlignment(Qt::AlignmentFlag::AlignLeading|Qt::AlignmentFlag::AlignLeft|Qt::AlignmentFlag::AlignTop);

        gridLayout->addWidget(text, 0, 2, 1, 1);

        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName("verticalLayout");
        certificateLayout = new QHBoxLayout();
        certificateLayout->setObjectName("certificateLayout");
        certDetailsButton = new QPushButton(SslErrorDialog);
        certDetailsButton->setObjectName("certDetailsButton");

        certificateLayout->addWidget(certDetailsButton);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        certificateLayout->addItem(horizontalSpacer);


        verticalLayout->addLayout(certificateLayout);

        certTabWidget = new QTabWidget(SslErrorDialog);
        certTabWidget->setObjectName("certTabWidget");
        certTabWidget->setTabBarAutoHide(false);

        verticalLayout->addWidget(certTabWidget);

        verticalSpacer = new QSpacerItem(20, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::MinimumExpanding);

        verticalLayout->addItem(verticalSpacer);

        verticalLayout->setStretch(1, 1);

        gridLayout->addLayout(verticalLayout, 1, 0, 1, 3);

        gridLayout->setRowStretch(1, 1);

        retranslateUi(SslErrorDialog);

        certTabWidget->setCurrentIndex(-1);


        QMetaObject::connectSlotsByName(SslErrorDialog);
    } // setupUi

    void retranslateUi(QDialog *SslErrorDialog)
    {
        SslErrorDialog->setWindowTitle(QCoreApplication::translate("SslErrorDialog", "SSL Certificate Error!", nullptr));
        certDetailsButton->setText(QCoreApplication::translate("SslErrorDialog", "Toggle Certificate Details", nullptr));
    } // retranslateUi

};

namespace Ui {
    class SslErrorDialog: public Ui_SslErrorDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_SSLERRORDIALOG_H
