/********************************************************************************
** Form generated from reading UI file 'autofillwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_AUTOFILLWIDGET_H
#define UI_AUTOFILLWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_AutoFillWidget
{
public:
    QGridLayout *gridLayout1;
    QGridLayout *gridLayout2;
    QLabel *label;
    QGridLayout *gridLayout;

    void setupUi(QWidget *AutoFillWidget)
    {
        if (AutoFillWidget->objectName().isEmpty())
            AutoFillWidget->setObjectName("AutoFillWidget");
        gridLayout1 = new QGridLayout(AutoFillWidget);
        gridLayout1->setObjectName("gridLayout1");
        gridLayout2 = new QGridLayout();
        gridLayout2->setObjectName("gridLayout2");
        label = new QLabel(AutoFillWidget);
        label->setObjectName("label");
        label->setAlignment(Qt::AlignCenter);

        gridLayout2->addWidget(label, 0, 0, 1, 1);


        gridLayout1->addLayout(gridLayout2, 0, 0, 1, 1);

        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");

        gridLayout1->addLayout(gridLayout, 1, 0, 1, 1);


        retranslateUi(AutoFillWidget);

        QMetaObject::connectSlotsByName(AutoFillWidget);
    } // setupUi

    void retranslateUi(QWidget *AutoFillWidget)
    {
        label->setText(QCoreApplication::translate("AutoFillWidget", "Login as:", nullptr));
        (void)AutoFillWidget;
    } // retranslateUi

};

namespace Ui {
    class AutoFillWidget: public Ui_AutoFillWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_AUTOFILLWIDGET_H
