/********************************************************************************
** Form generated from reading UI file 'sbi_proxywidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SBI_PROXYWIDGET_H
#define UI_SBI_PROXYWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_SBI_ProxyWidget
{
public:
    QGridLayout *gridLayout;
    QHBoxLayout *horizontalLayout_9;
    QComboBox *proxyType;
    QLineEdit *proxyServer;
    QLabel *label_37;
    QLineEdit *proxyPort;
    QSpacerItem *horizontalSpacer;
    QHBoxLayout *horizontalLayout_24;
    QLabel *label_56;
    QLineEdit *proxyUsername;
    QLabel *label_57;
    QLineEdit *proxyPassword;
    QSpacerItem *horizontalSpacer_28;
    QRadioButton *systemProxy;
    QRadioButton *manualProxy;
    QSpacerItem *verticalSpacer;
    QFrame *httpsCredentialsLayout_2;
    QHBoxLayout *httpsCredentialsLayout;

    void setupUi(QWidget *SBI_ProxyWidget)
    {
        if (SBI_ProxyWidget->objectName().isEmpty())
            SBI_ProxyWidget->setObjectName("SBI_ProxyWidget");
        SBI_ProxyWidget->resize(558, 398);
        gridLayout = new QGridLayout(SBI_ProxyWidget);
        gridLayout->setObjectName("gridLayout");
        horizontalLayout_9 = new QHBoxLayout();
        horizontalLayout_9->setObjectName("horizontalLayout_9");
        proxyType = new QComboBox(SBI_ProxyWidget);
        proxyType->addItem(QString());
        proxyType->addItem(QString());
        proxyType->setObjectName("proxyType");

        horizontalLayout_9->addWidget(proxyType);

        proxyServer = new QLineEdit(SBI_ProxyWidget);
        proxyServer->setObjectName("proxyServer");

        horizontalLayout_9->addWidget(proxyServer);

        label_37 = new QLabel(SBI_ProxyWidget);
        label_37->setObjectName("label_37");

        horizontalLayout_9->addWidget(label_37);

        proxyPort = new QLineEdit(SBI_ProxyWidget);
        proxyPort->setObjectName("proxyPort");
        proxyPort->setMaximumSize(QSize(50, 16777215));

        horizontalLayout_9->addWidget(proxyPort);


        gridLayout->addLayout(horizontalLayout_9, 2, 1, 1, 1);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer, 2, 0, 1, 1);

        horizontalLayout_24 = new QHBoxLayout();
        horizontalLayout_24->setObjectName("horizontalLayout_24");
        label_56 = new QLabel(SBI_ProxyWidget);
        label_56->setObjectName("label_56");

        horizontalLayout_24->addWidget(label_56);

        proxyUsername = new QLineEdit(SBI_ProxyWidget);
        proxyUsername->setObjectName("proxyUsername");

        horizontalLayout_24->addWidget(proxyUsername);

        label_57 = new QLabel(SBI_ProxyWidget);
        label_57->setObjectName("label_57");

        horizontalLayout_24->addWidget(label_57);

        proxyPassword = new QLineEdit(SBI_ProxyWidget);
        proxyPassword->setObjectName("proxyPassword");

        horizontalLayout_24->addWidget(proxyPassword);

        horizontalSpacer_28 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_24->addItem(horizontalSpacer_28);


        gridLayout->addLayout(horizontalLayout_24, 3, 1, 1, 1);

        systemProxy = new QRadioButton(SBI_ProxyWidget);
        systemProxy->setObjectName("systemProxy");

        gridLayout->addWidget(systemProxy, 0, 0, 1, 2);

        manualProxy = new QRadioButton(SBI_ProxyWidget);
        manualProxy->setObjectName("manualProxy");

        gridLayout->addWidget(manualProxy, 1, 0, 1, 2);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer, 6, 1, 1, 1);

        httpsCredentialsLayout_2 = new QFrame(SBI_ProxyWidget);
        httpsCredentialsLayout_2->setObjectName("httpsCredentialsLayout_2");
        httpsCredentialsLayout = new QHBoxLayout(httpsCredentialsLayout_2);
        httpsCredentialsLayout->setObjectName("httpsCredentialsLayout");

        gridLayout->addWidget(httpsCredentialsLayout_2, 5, 1, 1, 1);


        retranslateUi(SBI_ProxyWidget);

        QMetaObject::connectSlotsByName(SBI_ProxyWidget);
    } // setupUi

    void retranslateUi(QWidget *SBI_ProxyWidget)
    {
        SBI_ProxyWidget->setWindowTitle(QCoreApplication::translate("SBI_ProxyWidget", "Form", nullptr));
        proxyType->setItemText(0, QCoreApplication::translate("SBI_ProxyWidget", "HTTP", nullptr));
        proxyType->setItemText(1, QCoreApplication::translate("SBI_ProxyWidget", "SOCKS5", nullptr));

        label_37->setText(QCoreApplication::translate("SBI_ProxyWidget", "Port:", nullptr));
        label_56->setText(QCoreApplication::translate("SBI_ProxyWidget", "Username:", nullptr));
        label_57->setText(QCoreApplication::translate("SBI_ProxyWidget", "Password:", nullptr));
        systemProxy->setText(QCoreApplication::translate("SBI_ProxyWidget", "S&ystem proxy configuration", nullptr));
        manualProxy->setText(QCoreApplication::translate("SBI_ProxyWidget", "&Manual configuration", nullptr));
    } // retranslateUi

};

namespace Ui {
    class SBI_ProxyWidget: public Ui_SBI_ProxyWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_SBI_PROXYWIDGET_H
