/********************************************************************************
** Form generated from reading UI file 'tabmanagerwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_TABMANAGERWIDGET_H
#define UI_TABMANAGERWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "lineedit.h"
#include "tabmanagerwidget.h"

QT_BEGIN_NAMESPACE

class Ui_TabManagerWidget
{
public:
    QVBoxLayout *verticalLayout;
    LineEdit *filterBar;
    TabTreeWidget *treeWidget;

    void setupUi(QWidget *TabManagerWidget)
    {
        if (TabManagerWidget->objectName().isEmpty())
            TabManagerWidget->setObjectName("TabManagerWidget");
        TabManagerWidget->resize(266, 368);
        verticalLayout = new QVBoxLayout(TabManagerWidget);
        verticalLayout->setSpacing(0);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(2, 2, 2, 2);
        filterBar = new LineEdit(TabManagerWidget);
        filterBar->setObjectName("filterBar");

        verticalLayout->addWidget(filterBar);

        treeWidget = new TabTreeWidget(TabManagerWidget);
        QTreeWidgetItem *__qtreewidgetitem = new QTreeWidgetItem();
        __qtreewidgetitem->setText(0, QString::fromUtf8("1"));
        treeWidget->setHeaderItem(__qtreewidgetitem);
        treeWidget->setObjectName("treeWidget");
        treeWidget->header()->setVisible(false);

        verticalLayout->addWidget(treeWidget);


        retranslateUi(TabManagerWidget);

        QMetaObject::connectSlotsByName(TabManagerWidget);
    } // setupUi

    void retranslateUi(QWidget *TabManagerWidget)
    {
        TabManagerWidget->setWindowTitle(QCoreApplication::translate("TabManagerWidget", "Tab Manager", nullptr));
    } // retranslateUi

};

namespace Ui {
    class TabManagerWidget: public Ui_TabManagerWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_TABMANAGERWIDGET_H
