/********************************************************************************
** Form generated from reading UI file 'clearprivatedata.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CLEARPRIVATEDATA_H
#define UI_CLEARPRIVATEDATA_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>

QT_BEGIN_NAMESPACE

class Ui_ClearPrivateData
{
public:
    QGridLayout *gridLayout;
    QLabel *label_3;
    QPushButton *editCookies;
    QComboBox *historyLength;
    QCheckBox *history;
    QLabel *label_2;
    QCheckBox *localStorage;
    QPushButton *clear;
    QDialogButtonBox *buttonBox;
    QCheckBox *databases;
    QCheckBox *cache;
    QPushButton *optimizeDb;
    QCheckBox *cookies;
    QFrame *line;
    QLabel *label_5;
    QSpacerItem *verticalSpacer;

    void setupUi(QDialog *ClearPrivateData)
    {
        if (ClearPrivateData->objectName().isEmpty())
            ClearPrivateData->setObjectName("ClearPrivateData");
        ClearPrivateData->resize(377, 324);
        gridLayout = new QGridLayout(ClearPrivateData);
        gridLayout->setObjectName("gridLayout");
        label_3 = new QLabel(ClearPrivateData);
        label_3->setObjectName("label_3");

        gridLayout->addWidget(label_3, 0, 0, 1, 1);

        editCookies = new QPushButton(ClearPrivateData);
        editCookies->setObjectName("editCookies");

        gridLayout->addWidget(editCookies, 6, 1, 1, 1);

        historyLength = new QComboBox(ClearPrivateData);
        historyLength->addItem(QString());
        historyLength->addItem(QString());
        historyLength->addItem(QString());
        historyLength->addItem(QString());
        historyLength->setObjectName("historyLength");
        historyLength->setEnabled(false);

        gridLayout->addWidget(historyLength, 2, 1, 1, 1);

        history = new QCheckBox(ClearPrivateData);
        history->setObjectName("history");
        history->setChecked(false);

        gridLayout->addWidget(history, 2, 0, 1, 1);

        label_2 = new QLabel(ClearPrivateData);
        label_2->setObjectName("label_2");

        gridLayout->addWidget(label_2, 1, 0, 1, 2);

        localStorage = new QCheckBox(ClearPrivateData);
        localStorage->setObjectName("localStorage");
        localStorage->setChecked(true);

        gridLayout->addWidget(localStorage, 4, 0, 1, 1);

        clear = new QPushButton(ClearPrivateData);
        clear->setObjectName("clear");
        clear->setMinimumSize(QSize(90, 0));

        gridLayout->addWidget(clear, 10, 0, 1, 1);

        buttonBox = new QDialogButtonBox(ClearPrivateData);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel);
        buttonBox->setCenterButtons(false);

        gridLayout->addWidget(buttonBox, 10, 1, 1, 1);

        databases = new QCheckBox(ClearPrivateData);
        databases->setObjectName("databases");
        databases->setChecked(true);

        gridLayout->addWidget(databases, 3, 0, 1, 1);

        cache = new QCheckBox(ClearPrivateData);
        cache->setObjectName("cache");
        cache->setChecked(true);

        gridLayout->addWidget(cache, 5, 0, 1, 1);

        optimizeDb = new QPushButton(ClearPrivateData);
        optimizeDb->setObjectName("optimizeDb");

        gridLayout->addWidget(optimizeDb, 8, 1, 1, 1);

        cookies = new QCheckBox(ClearPrivateData);
        cookies->setObjectName("cookies");
        cookies->setChecked(false);

        gridLayout->addWidget(cookies, 6, 0, 1, 1);

        line = new QFrame(ClearPrivateData);
        line->setObjectName("line");
        line->setFrameShape(QFrame::Shape::HLine);
        line->setFrameShadow(QFrame::Shadow::Sunken);

        gridLayout->addWidget(line, 9, 0, 1, 2);

        label_5 = new QLabel(ClearPrivateData);
        label_5->setObjectName("label_5");

        gridLayout->addWidget(label_5, 8, 0, 1, 1);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer, 7, 0, 1, 1);


        retranslateUi(ClearPrivateData);
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, ClearPrivateData, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(ClearPrivateData);
    } // setupUi

    void retranslateUi(QDialog *ClearPrivateData)
    {
        ClearPrivateData->setWindowTitle(QCoreApplication::translate("ClearPrivateData", "Clear Recent History", nullptr));
        label_3->setText(QCoreApplication::translate("ClearPrivateData", "<b>Clear Recent History</b>", nullptr));
        editCookies->setText(QCoreApplication::translate("ClearPrivateData", "Edit cookies", nullptr));
        historyLength->setItemText(0, QCoreApplication::translate("ClearPrivateData", "Earlier Today", nullptr));
        historyLength->setItemText(1, QCoreApplication::translate("ClearPrivateData", "Week", nullptr));
        historyLength->setItemText(2, QCoreApplication::translate("ClearPrivateData", "Month", nullptr));
        historyLength->setItemText(3, QCoreApplication::translate("ClearPrivateData", "All", nullptr));

        history->setText(QCoreApplication::translate("ClearPrivateData", "Visited pages history from:", nullptr));
        label_2->setText(QCoreApplication::translate("ClearPrivateData", "Checked items will be cleared upon clicking the Clear button.", nullptr));
        localStorage->setText(QCoreApplication::translate("ClearPrivateData", "Local storage", nullptr));
        clear->setText(QCoreApplication::translate("ClearPrivateData", "Clear", nullptr));
        databases->setText(QCoreApplication::translate("ClearPrivateData", "Web databases", nullptr));
        cache->setText(QCoreApplication::translate("ClearPrivateData", "Cache", nullptr));
        optimizeDb->setText(QCoreApplication::translate("ClearPrivateData", "Optimize database", nullptr));
        cookies->setText(QCoreApplication::translate("ClearPrivateData", "Cookies", nullptr));
        label_5->setText(QCoreApplication::translate("ClearPrivateData", "Database", nullptr));
    } // retranslateUi

};

namespace Ui {
    class ClearPrivateData: public Ui_ClearPrivateData {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_CLEARPRIVATEDATA_H
