/****************************************************************************
** Meta object code from reading C++ file 'webpage.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../falkon-26.04.2/src/lib/webengine/webpage.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'webpage.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7WebPageE_t {};
} // unnamed namespace

template <> constexpr inline auto WebPage::qt_create_metaobjectdata<qt_meta_tag_ZN7WebPageE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "WebPage",
        "privacyChanged",
        "",
        "status",
        "printRequested",
        "navigationRequestAccepted",
        "QUrl",
        "url",
        "QWebEnginePage::NavigationType",
        "type",
        "isMainFrame",
        "progress",
        "prog",
        "finished",
        "urlChanged",
        "watchedFileChanged",
        "file",
        "windowCloseRequested",
        "fullScreenRequested",
        "QWebEngineFullScreenRequest",
        "fullScreenRequest",
        "featurePermissionRequested",
        "origin",
        "QWebEnginePage::Feature",
        "feature",
        "renderProcessTerminated",
        "QWebEnginePage::RenderProcessTerminationStatus",
        "terminationStatus",
        "exitCode",
        "onCertificateError",
        "QWebEngineCertificateError",
        "error",
        "onNewWindowRequested",
        "QWebEngineNewWindowRequest&",
        "request"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'privacyChanged'
        QtMocHelpers::SignalData<void(bool)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Signal 'printRequested'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'navigationRequestAccepted'
        QtMocHelpers::SignalData<void(const QUrl &, QWebEnginePage::NavigationType, bool)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 }, { 0x80000000 | 8, 9 }, { QMetaType::Bool, 10 },
        }}),
        // Slot 'progress'
        QtMocHelpers::SlotData<void(int)>(11, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Int, 12 },
        }}),
        // Slot 'finished'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'urlChanged'
        QtMocHelpers::SlotData<void(const QUrl &)>(14, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Slot 'watchedFileChanged'
        QtMocHelpers::SlotData<void(const QString &)>(15, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 16 },
        }}),
        // Slot 'windowCloseRequested'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'fullScreenRequested'
        QtMocHelpers::SlotData<void(QWebEngineFullScreenRequest)>(18, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 19, 20 },
        }}),
        // Slot 'featurePermissionRequested'
        QtMocHelpers::SlotData<void(const QUrl &, const QWebEnginePage::Feature &)>(21, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 6, 22 }, { 0x80000000 | 23, 24 },
        }}),
        // Slot 'renderProcessTerminated'
        QtMocHelpers::SlotData<void(QWebEnginePage::RenderProcessTerminationStatus, int)>(25, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 26, 27 }, { QMetaType::Int, 28 },
        }}),
        // Slot 'onCertificateError'
        QtMocHelpers::SlotData<void(QWebEngineCertificateError)>(29, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 30, 31 },
        }}),
        // Slot 'onNewWindowRequested'
        QtMocHelpers::SlotData<void(QWebEngineNewWindowRequest &)>(32, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 33, 34 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<WebPage, qt_meta_tag_ZN7WebPageE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject WebPage::staticMetaObject = { {
    QMetaObject::SuperData::link<QWebEnginePage::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7WebPageE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7WebPageE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7WebPageE_t>.metaTypes,
    nullptr
} };

void WebPage::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<WebPage *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->privacyChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 1: _t->printRequested(); break;
        case 2: _t->navigationRequestAccepted((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QWebEnginePage::NavigationType>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 3: _t->progress((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 4: _t->finished(); break;
        case 5: _t->urlChanged((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 6: _t->watchedFileChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 7: _t->windowCloseRequested(); break;
        case 8: _t->fullScreenRequested((*reinterpret_cast<std::add_pointer_t<QWebEngineFullScreenRequest>>(_a[1]))); break;
        case 9: _t->featurePermissionRequested((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QWebEnginePage::Feature>>(_a[2]))); break;
        case 10: _t->renderProcessTerminated((*reinterpret_cast<std::add_pointer_t<QWebEnginePage::RenderProcessTerminationStatus>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 11: _t->onCertificateError((*reinterpret_cast<std::add_pointer_t<QWebEngineCertificateError>>(_a[1]))); break;
        case 12: _t->onNewWindowRequested((*reinterpret_cast<std::add_pointer_t<QWebEngineNewWindowRequest&>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (WebPage::*)(bool )>(_a, &WebPage::privacyChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (WebPage::*)()>(_a, &WebPage::printRequested, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (WebPage::*)(const QUrl & , QWebEnginePage::NavigationType , bool )>(_a, &WebPage::navigationRequestAccepted, 2))
            return;
    }
}

const QMetaObject *WebPage::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *WebPage::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7WebPageE_t>.strings))
        return static_cast<void*>(this);
    return QWebEnginePage::qt_metacast(_clname);
}

int WebPage::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWebEnginePage::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 13;
    }
    return _id;
}

// SIGNAL 0
void WebPage::privacyChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void WebPage::printRequested()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void WebPage::navigationRequestAccepted(const QUrl & _t1, QWebEnginePage::NavigationType _t2, bool _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2, _t3);
}
QT_WARNING_POP
